package com.github.braillesystems.learnbraille.res

import com.github.braillesystems.learnbraille.data.dsl.InfoInterpolation
import com.github.braillesystems.learnbraille.data.dsl.annotate
import com.github.braillesystems.learnbraille.data.dsl.lessons
import com.github.braillesystems.learnbraille.data.entities.*
import com.github.braillesystems.learnbraille.data.entities.BrailleDot.E
import com.github.braillesystems.learnbraille.data.entities.BrailleDot.F
import com.github.braillesystems.learnbraille.res.PunctuationSigns.Hyphen

internal val golubinaIntroLessons by lessons {

    lesson(
        name = "Знакомство с шеститочием"
    ) {
        +FirstInfo(
            """
                Перед Вами пошаговый курс для обучения с нуля системе Луи Брайля. Курс предназначен 
                для взрослых незрячих и детей старшего школьного возраста, недавно потерявших зрение,
                а также для самостоятельного освоения рельефно-точечного шрифта родственниками 
                инвалидов по зрению, специалистами по реабилитации и студентами-тифлопедагогами.
                <br>
                Курс построен на основе учебного пособия по изучению системы Л. Брайля. 
                Автор-составитель - тифлопедагог В. В. Голубина. Методическое консультирование
                осуществлялось тифлопедагогом В. Н. Воробьёвой.
                <br>
                В течение курса Вы ознакомитесь с обозначениями букв (русских, латинских и греческих),
                цифр, знаков препинания и специальных символов (цифровой знак и другие).
                В некоторых шагах предлагается выполнять задания, используя указанное пособие.
                Если Вам будет непонятно, как пользоваться курсом, Вы в любой момент можете вызвать справку
                по разделу, нажав кнопку "справка" в правом верхнем углу экрана.
            """
        )
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson. Тренировка чтения и ввода отдельных комбинаций.</b>
                <br><br>
                В системе Брайля основой любого символа является шеститочие, в котором точки 
                расположены в два столбца по три точки. Каждая точка имеет определённый порядковый
                номер.
                <br>
                При письме точки в <b>правом</b> столбце имеют номера 1, 2, 3 сверху вниз, в <b>левом</b> -
                4, 5, 6 сверху вниз. При чтении лист переворачивается, и точки 1, 2, 3 <b>оказываются слева</b>. 
                <br>
                В приложении при демонстрации символов рядом с точками 1, 2, 3 мы ставим вертикальную черту.
                Если символ выведен "как при чтении", эта черта слева от шеститочия, если "как при письме", то справа.
                """
        })
        +ShowDots(
            text = "Перед Вами полное шеститочие: <br> точки 1, 2, 3, 4, 5, 6",
            brailleDots = BrailleDots(F, F, F, F, F, F)
        )
        +InputDots(text = "Введите все шесть точек", brailleDots = BrailleDots(F, F, F, F, F, F))
        +ShowDots(
            text = "Перед Вами символ шрифта Брайля - <br>" +
                    " точка номер один",
            brailleDots = BrailleDots(F, E, E, E, E, E)
        )
        +InputDots(text = "Введите точку один", brailleDots = BrailleDots(F, E, E, E, E, E))
        +Info(
            """
                В шаге с демонстрацией столбец с точками 1, 2, 3 находится слева,
                а в шаге с вводом - справа, потому что буквы пишутся на обороте листа, а для чтения 
                лист переворачивается.
                <br>
                Впрочем, порядок столбцов в этом приложении можно изменить кнопкой <b>"Режим письмо/чтение"</b>
                справа на экране над кнопкой <b>"Вперёд"</b>.
                <br>
                В настройках можно отключить "При вводе столбец с точками 1, 2, 3 справа". Тогда
                при заходе в любой шаг точки 1, 2, 3 будут слева, но это по-прежнему можно будет изменить,
                нажав кнопку <b>"Режим письмо/чтение"</b>.
                """
        )
        +ShowDots(
            text = "Перед Вами символ шрифта Брайля - <br>" +
                    " точка номер три",
            brailleDots = BrailleDots(E, E, F, E, E, E)
        )
        +InputDots(text = "Введите точку три", brailleDots = BrailleDots(E, E, F, E, E, E))
        +ShowDots(
            text = "Перед Вами символ шрифта Брайля - <br>" +
                    " точка номер пять",
            brailleDots = BrailleDots(E, E, E, E, F, E)
        )
        +InputDots(text = "Введите точку пять", brailleDots = BrailleDots(E, E, E, E, F, E))
        +InputDots(
            text = """Теперь выполним пять практических заданий без обучающей картинки. 
                      <br>
                      Введите комбинацию точек 1 и 3""",
            brailleDots = BrailleDots(F, E, F, E, E, E)
        )
        +InputDots(
            text = "Введите комбинацию: точки 4 и 6",
            brailleDots = BrailleDots(E, E, E, F, E, F)
        )
        +InputDots(
            text = "Введите комбинацию точек 1, 3, 4 и 6",
            brailleDots = BrailleDots(F, E, F, F, E, F)
        )
        +InputDots(
            text = "Введите комбинацию точек 1, 2, 3, 4 и 5",
            brailleDots = BrailleDots(F, F, F, F, F, E)
        )
        +InputDots(
            text = "Введите комбинацию точек 1, 2, 3, 4 и 6",
            brailleDots = BrailleDots(F, F, F, F, E, F)
        )
        +Info(
            """Откройте пособие на странице 12. 
                    В верхней строке 14 раз повторён символ полного шеститочия. 
                    <br>
                    Начиная со второй строки - тренировочные упражнения. 
                    Самостоятельно потренируйтесь читать отдельные комбинации точек."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +InputDots(
            text = """Введите "средние точки" 2 и 5""",
            brailleDots = BrailleDots(E, F, E, E, F, E)
        )
        +Info(
            """Запишите "средние точки" 2 и 5 на брайлевском приборе.
                  <br>
                  Совет: если у Вас нет возможности писать на брайлевском приборе, в разделе "Настройки" можно отключить
                  шаги, требующие обращения к брайлевскому прибору.
        """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """Урок $iLesson закончен. В следующем уроке мы изучим буквы А, Б, Ц, Д, Е."""
        })
    }

    lesson(
        name = "Русские буквы А, Б, Ц, Д, Е"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буквы А, Б, Ц, Д, Е.</b>
                    <br><br>
                    В нашем курсе буквы изучаются не в порядке русского алфавита, а в порядке 
                    <b>"ключа Брайля"</b>: сперва те, что состоят из двух верхних рядов точек, затем
                    остальные. Этот порядок пришёл к нам из латинского алфавита Луи Брайля. """
        })
        +Info(
            """Буква А обозначается одной точкой, точкой номер один.
                    Ознакомьтесь с ней в следующем шаге."""
        )
        +Show(content.symbols.getValue('А'))
        +Info(
            """Откройте пособие на странице 13. Вверху слева рельефно-графическое
                    изображение буквы А. Рядом после полного шеститочия пять раз повторена 
                    буква А точечным шрифтом."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('А'))
        slateStylusLine('А')
        +Show(content.symbols.getValue('Б'))
        +Info(
            """Снова изучим страницу 13 в пособии. Под строкой с буквой А - 
                    такая же с буквой Б."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Б'))
        slateStylusLine('Б')
        +Info(
            """
                    Буква Ц: точки 1 и 4
                    <br><br>
                    Ознакомьтесь с буквой Ц на странице 13 пособия. 
                    Строка с буквой Ц находится под строкой с буквой Б."""
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Show(content.symbols.getValue('Ц'))
        +Input(content.symbols.getValue('Ц'))
        +Show(content.symbols.getValue('Д'))
        +Input(content.symbols.getValue('Д'))
        +Info(
            """Последняя буква в этом уроке - буква Е. 
                    Она обозначается двумя точками: номер 1 и 5."""
        )
        +Show(content.symbols.getValue('Е'))
        +Input(content.symbols.getValue('Е'))
        +Info("""В следующих трёх шагах нужно ввести буквы Б, А, Ц (вместе это слово БАЦ).""")
        inputPhraseByLetters("БАЦ")
        +Info("""Теперь наберите в следующих трёх шагах, вводя букву за буквой, слово ДЕД.""")
        inputPhraseByLetters("ДЕД")
        +Info("""Далее в следующих четырёх шагах введите слово БАБА.""")
        inputPhraseByLetters("БАБА")
        +Info(
            """Запишите на брайлевском приборе три строки: из букв Ц, Д и Е.
                    <br>
                    После этого запишите через пробел слова: БАЦ, ДЕД, БАБА.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info("""Отметим, что правила написания букв и других символов соответствуют
                 <b>стандартам общеупотребительного Брайля</b>, принятым в России, которые 
                 утверждены Комиссией Центрального 
                 правления Всероссийского общества слепых в 2013 году.
                 Подробнее об этом можно прочесть на сайте комиссии:
                 <br>
                 <a href="http://www.chtenie.spb.ru/komissia.htm">www.chtenie.spb.ru/komissia.htm</a>
           """
        )
        +Info(InfoInterpolation.run {
            """Урок $iLesson закончен. В следующем занятии займёмся повторением букв А, Б, Ц, Д, Е
                 и потренируемся писать цифры от 1 до 5, образуемые с помощью этих букв. Рекомендуем
                 в дополнение к уроку потренироваться вводить изученные буквы в разделе "Практика"."""
        })
    }

    lesson(
        name = "Цифры от 1 до 5"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Цифры от 1 до 5.</b>
                    <br><br>
                    В этом уроке мы начнём изучать цифры. Но для начала повторим пройденное.
                    В следующих шагах введите буквы, изученные в прошлом уроке."""
        })
        inputChars("АБЦДЕ")
        +Info(
            """
                    Переходим к изучению цифр.
                    <br>
                    Запомним, 10 символов первой строки «Ключа Брайля» обозначают 10 латинских и 
                    русских букв, а также арабские цифры.
                    <br>
                    Для того, чтобы букву преобразовать в цифру, перед ней ставится 
                    <b>«Цифровой знак»</b>. Он обозначается четырьмя точками: номер 3, 4, 5 и 6.
                    """
        )
        +Show(content.markers.getValue(MarkerType.NumberSign))
        +Info(
            """
                В пособии на странице 14, после страницы с буквами от А до Е - цифровой знак.
                Найдите четвёртую сверху строчку. В ней цифровой знак повторён пять раз.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.markers.getValue(MarkerType.NumberSign))
        +Info(
            """
                    В следующих шагах изучим цифры 1, 2, 3, 4, 5.
                    Они получаются из букв А, Б, Ц, Д, Е добавлением цифрового знака.
                    Например, цифра 3, как и число 3 - это цифровой знак + Ц.
                    Число двадцать четыре - это цифровой знак, затем буквы Б и Д. 
                    В следующих шагах просмотрите, а затем введите число «двенадцать тысяч
                    триста сорок пять»."""
        )
        +Show(content.markers.getValue(MarkerType.NumberSign))
        for (char in "12345") {
            +Show(content.symbols.getValue(char))
        }
        inputNumber(12345)
        +Info(
            """
                На пятой сверху строчке на странице 14 пособия, под строкой с цифровым знаком,
                написаны цифры от одного до пяти.
                Изучите каждую цифру.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """
                    Запишите, используя брайлевский прибор, цифровой знак и за ним изученные пять цифр.
                    Получится число "двенадцать тысяч триста сорок пять".
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson пройден! Рекомендуем самостоятельно изучить цифры и числа на странице 15
                    в пособии (внизу страницы).
                    <br>
                    Также цифры можно повторять в разделе приложения "Практика".
                    В разделе "Практика" не нужно вводить перед цифрами цифровой знак,
                    но при письме обязательно ставить его перед каждым числом."""
        })
    }

    lesson(
        name = "Буквы Ф, Г и цифры 6, 7"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буквы Ф, Г и цифры 6, 7.</b>
                    <br><br>
                    Перед прохождением нового материала повторим пройденное.
                    В следующих пяти шагах нужно ввести буквы Б, E, Д, А (вместе это слово БЕДА)."""
        })
        inputPhraseByLetters("БЕДА")
        +Info(
            """
                    Теперь познакомимся с буквами Ф и Г.
                    <br>
                    Буква Ф обозначается точками 1, 2 и 4.
                    <br>
                    Буква Г - точки 1, 2, 4 и 5.
                    <br>
                    В следующих шагах нужно ознакомиться с буквами и ввести их."""
        )
        +Show(content.symbols.getValue('Ф'))
        +Info(
            """
                Откройте страницу 15 в пособии. Вверху страницы найдите рельефно-графическое
                изображение буквы Ф и рядом букву Ф, пять раз написанную рельефно-точечным шрифтом.
                """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Ф'))
        slateStylusLine('Ф')
        +Show(content.symbols.getValue('Г'))
        +Info(
            """
                В пособии под буквой Ф - буква Г. Изучите её графическое представление
                и точечный состав.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Г'))
        slateStylusLine('Г')
        +Info(
            """
                    В следующих трёх шагах введите по буквам слово БЕГ."""
        )
        inputPhraseByLetters("БЕГ")
        +Info(
            """
                    Цифровой знак и буква Ф за ним обозначают арабскую цифру 6 или число 6.
                    <br>
                    Цифровой знак и буква Г за ним - это семёрка.
                    <br>
                    В следующих трёх шагах введите число ШЕСТЬДЕСЯТ СЕМЬ."""
        )
        inputNumber(67)
        +Info(
            """Напишите слово БЕГ и число "ШЕСТДЕСЯТ СЕМЬ" при помощи брайлевского прибора."""
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """Поздравляем! Урок $iLesson пройден."""
        })
    }

    lesson(
        name = "Буква Х и цифра 8"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Х и цифра 8.</b>
                    <br><br>
                    По окончании этого урока Вы узнаете букву Х и цифру 8. 
                    Но перед изучением нового повторим пройденное. Введите по буквам слово ФЕБ."""
        })
        inputPhraseByLetters("ФЕБ")
        +Info("""В следующих шести шагах введите по буквам слово БАГДАД.""")
        inputPhraseByLetters("БАГДАД")
        +Info(
            """Наберите в следующих четырёх шагах число СТО ДВАДЦАТЬ ТРИ, поставив перед ним
               цифровой знак.
            """
        )
        inputNumber(123)
        +Info(
            """
                    Буква Х  обозначается точками 1, 2 и 5.
                    <br>
                    Цифра 8 - это цифровой знак и буква Х.
                    """
        )

        +Show(content.symbols.getValue('Х'))
        +Info(
            """
                Откройте страницу 16 в пособии Голубиной. В верхней части страницы найдите
                рельефно-графическую букву Х и рядом строку из пяти брайлевских букв Х.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Х'))
        +Input(content.symbols.getValue('8'))
        slateStylusLine('Х')
        +Info("""В следующих шагах введите по буквам слово ЦЕХ""")
        inputPhraseByLetters("ЦЕХ")
        +Info("""Наберите восклицание АХ""")
        inputPhraseByLetters("АХ")
        +Info("""Далее введите, поставив цифровой знак, число "ВОСЕМЬСОТ СЕМЬДЕСЯТ ШЕСТЬ" """)
        inputNumber(876)
        +Info(
            """Введите на брайлевском приборе слова ЦЕХ, АХ и число ВОСЕМЬСОТ СЕМЬДЕСЯТ ШЕСТЬ."""
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson пройден!
                    <br>
                    На следующем занятии мы освоим буквы И и Ж, а также цифры 9 и 0"""
        })
    }

    lesson(
        name = "Буквы Ж, И и цифры 9, 0"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буквы Ж, И и цифры 9, 0</b>
                    <br><br>
                    Буква И - это точки 2 и 4.
                    Этот же символ с добавлением цифрового знака обозначает цифру 9.
                    <br>
                    Буква Ж - это точки 2, 4 и 5.
                    Цифровой знак и буква Ж образуют цифру 0.
                    """
        })
        +Info(
            """
                Раскройте пособие на странице 17. В верхней части листа найдите рельефно-графические
                и рельефно-точечные изображения букв Ж и И.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ж')
        slateStylusLine('И')
        +Info(
            """Введите буквы, составляющие слово БАГАЖ"""
        )
        inputPhraseByLetters("БАГАЖ")
        +Info(
            """Введите буквы, составляющие слово ЖАЖДА"""
        )
        inputPhraseByLetters("ЖАЖДА")
        +Info(
            """Напомним, буква И кодируется двумя точками с номерами 2 и 4.
                    Введите буквы, образующие слово ГИД"""
        )
        inputPhraseByLetters("ГИД")
        +Info(
            """Введите буквы, которые образуют слово ИЖИЦА"""
        )
        inputPhraseByLetters("ИЖИЦА")
        +Info(
            """Введите по символам число 850"""
        )
        inputNumber(850)
        +Info(
            """
                    Напишите с помощью брайлевского прибора слова, набранные до этого на экране:
                    <br>
                    БАГДАД, ЖАЖДА, ГИД, ИЖИЦА и число ВОСЕМЬСОТ ПЯТЬДЕСЯТ.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson закончен. Теперь Вы, помимо букв, знаете все цифры.
                    Примеры слов и чисел к этому уроку можно найти в пособии внизу страницы 17.
                    <br>
                    Следующий урок посвящён буквам К, Л и М."""
        })
    }

    lesson(
        name = "Буквы К, Л, М"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буквы К, Л, М</b>
                    <br><br>
                    До сих пор мы изучали только буквы, образованные верхними четырьмя точками,
                    то есть точками 1, 2, 4, 5. В нескольких следующих уроках будут рассмотрены
                    буквы, содержащие, помимо того, точку три.
                    <br>
                    Перед занятием повторим пройденное. Введите по буквам слово ЕЖИХА.
                    """
        })
        inputPhraseByLetters("ЕЖИХА")
        +Info(
            """
                    Теперь перейдём к изучению материала.
                    <br>
                    Буква К: точки 1 и 3. Заметьте, она получается добавлением точки 3 к букве А.
                    <br>
                    Буква Л: точки 1, 2, 3. Как буква Б, но ещё с точкой 3.
                    <br>
                    Ознакомьтесь с этими буквами в следующих двух шагах.
                    """
        )
        +Show(content.symbols.getValue('К'))
        +Show(content.symbols.getValue('Л'))
        +Info(
            """
                    Сейчас предлагаем Вам найти страницу 19 в пособии, где вверху изображена рельефная
                    буква К и рядом с ней строка из пяти брайлевских букв К. Ниже находится буква Л.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('К')
        slateStylusLine('Л')
        +Info(
            """Введите по буквам слово КЛАД"""
        )
        inputPhraseByLetters("КЛАД")
        +Info(
            """Введите по буквам слово БЕЛКА"""
        )
        inputPhraseByLetters("БЕЛКА")
        +Info(
            """
                    Сегодня осталось изучить букву М.
                    <br>
                    Буква М обозначается точками 1, 3 и 4. Она получается из буквы Ц 
                    при добавлении точки 3.
                    <br>
                    В следующем шаге буква М выведена на экран.
                    """
        )
        +Show(content.symbols.getValue('М'))
        +Info(
            """
                    На той же странице 19 в пособии найдите и прочтите строку с буквой М
                    под строками с буквами К, Л.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('М')
        +Info(
            """В следующих трёх шагах ведите по буквам слово МЕЛ"""
        )
        inputPhraseByLetters("МЕЛ")
        +Info(
            """Введите по буквам слово МАК"""
        )
        inputPhraseByLetters("МАК")
        +Info(
            """Напоследок введите по буквам слово ФИАЛКА"""
        )
        inputPhraseByLetters("ФИАЛКА")
        +Info(
            """
                    Напишите на брайлевском приборе пройденные в уроке слова:
                    <br>
                    КЛАД, БЕЛКА, МЕЛ, МАК, ФИАЛКА.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Мы подошли к концу урока $iLesson.
                    <br>
                    Буквам К, Л, М посвящены страницы 19 и 20 пособия; желательно
                    повторить материал, прочитав слова и числа на этих страницах.
                    <br>
                    На следующем занятии мы узнаем, как обозначается буква Н."""
        })
    }

    lesson(
        name = "Буква Н"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Н.</b>
                    <br><br>
                    Начнём занятие с повторения. Введите по буквам слово КАМБАЛА.
                    """
        })
        inputPhraseByLetters("КАМБАЛА")
        +Info(
            """
                    Отлично, теперь познакомимся с буквой Н.
                    <br>
                    Буква Н обозначается четырьмя точками: 1, 3, 4 и 5. 
                    Она образована точками буквы Д с добавлением точки номер 3.
                    <br>
                    В следующем шаге ознакомьтесь с этой буквой.
                    """
        )
        +Show(content.symbols.getValue('Н'))
        +Info(
            """
                    Раскройте страницу 21 пособия и найдите вверху букву Н.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('Н'))
        slateStylusLine('Н')
        +Info(
            """Введите по буквам слово БАНАН"""
        )
        inputPhraseByLetters("БАНАН")
        +Info(
            """Введите по буквам слово ЦЕНА"""
        )
        inputPhraseByLetters("ЦЕНА")
        +Info(
            """Теперь введите по буквам слово БЛАНК"""
        )
        inputPhraseByLetters("БЛАНК")
        +Info(
            """
                    С помощью брайлевского прибора запишите введённые ранее слова:
                    <br>
                    БАНАН, ЦЕНА, БЛАНК.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    На этом урок $iLesson завершается. Для закрепления материала полезно прочесть
                    текст на страницах 21 и 22 в пособии.
                    <br>
                    В следующий раз изучим букву О и знак препинания ЗАПЯТАЯ.
                    """
        })
    }
    lesson(
        name = "Буква О и знак препинания 'Запятая'"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква О и знак препинания "Запятая".</b>
                    <br><br>
                    Как обычно, в начале занятия повторим пройденное.
                    Введите по буквам слово НАДЕЖДА.
                    """
        })
        inputPhraseByLetters("НАДЕЖДА")
        +Info(
            """
                    Идём дальше: теперь изучим букву 'О'.
                    <br>
                    Буква 'О' - это точки 1, 3 и 5. Если помните, точками 1 и 5 
                    обозначается буква Е, а О образуется из Е добавлением точки 3.
                    """
        )
        +Show(content.symbols.getValue('О'))
        +Info(
            """
                    Возьмите пособие и откройте страницу 23. Сверху найдите букву О.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('О')

        +Info(
            """Наберите по буквам слово ОБЛАКО"""
        )
        inputPhraseByLetters("ОБЛАКО")
        +Info(
            """
                    Кратко ознакомимся со знаком 'Запятая'.
                    <br>
                    Запятая, как и буква А - только одна точка. Но если А - это точка 1, то запятая
                    - точка 2.
                    """
        )
        +Show(content.symbols.getValue(','))
        +Info(
            """Наберите по символам слово ЛОДКА и поставьте в конце запятую"""
        )
        inputPhraseByLetters("ЛОДКА,")
        +Info(
            """Аналогично предыдущему, введите слово КОФЕ и запятую"""
        )
        inputPhraseByLetters("КОФЕ,")
        +Info(
            """Напоследок введите слово ГЕОЛОГ и тоже поставьте запятую в конце"""
        )
        inputPhraseByLetters("ГЕОЛОГ,")
        +Info(
            """
                    Используя брайлевский прибор, запишите фразу:
                    <br>
                    БЕЛОЕ ОБЛАКО, БЛЕДНОЕ ЛИЦО, БЕЛОЕ МОЛОКО
                    <br>
                    разделяя перечисляемые элементы запятыми. Затем откройте страницу 24 пособия,
                    где записана эта фраза, и проверьте себя.
            """
        ).annotate(StepAnnotation.golubinaBookRequired, StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """Урок $iLesson подходит к концу. В следующем уроке нас ждёт изучение буквы П.
                    Материалы к этому занятию можно прочесть на страницах 23-24 в пособии.
            """
        })
    }
    lesson(
        name = "Буква П"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква П.</b>
                    <br><br>
                    В виде разминки перед уроком повторим изученные ранее символы.
                    Введите по буквам слово МОЛОКО и поставьте после него запятую.
                    """
        })
        inputPhraseByLetters("МОЛОКО,")
        +Info(
            """
                    Давайте познакомимся с буквой 'П'.
                    <br>
                    Буква 'П' представлена точками 1, 2, 3 и 4. Напомним, точки 1, 2 и 4 образуют
                    букву Ф. Букву П можно получить из Ф, добавив точку номер 3.
                    """
        )
        +Show(content.symbols.getValue('П'))
        +Info(
            """
                    Найдём букву П в пособии. Для этого раскройте страницу 25 и изучите верхнюю строку.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('П')
        +Info(
            """Введите отдельными символами слово ПЕНА"""
        )
        inputPhraseByLetters("ПЕНА")
        +Info(
            """Теперь нужно набрать по буквам слово ЛАМПА"""
        )
        inputPhraseByLetters("ЛАМПА")
        +Info(
            """Наберите по буквам слово ПЛАН"""
        )
        inputPhraseByLetters("ПЛАН")
        +Info(
            """И последнее в этом уроке: введите по буквам слово КАПКАН"""
        )
        inputPhraseByLetters("КАПКАН")
        +Info(InfoInterpolation.run {
            """
                Вот и пройден урок $iLesson. Следующее занятие отведено для изучения буквы Ч.
                Изученный урок полезно закрепить, прочтя слова на странице 25 в книге Голубиной.
            """
        })
    }

    lesson(
        name = "Буква Ч"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Ч.</b>
                    <br><br>
                    Перед началом работы немного повторим прошлые уроки.
                    Введите по буквам слово ХЛОПОК.
                    """
        })
        inputPhraseByLetters("ХЛОПОК")
        +Info(
            """Введите отдельными символами число 215, поставив перед ним цифровой знак"""
        )
        inputNumber(215)

        +Info(
            """
                    Переходим к изучению новой буквы: 'Ч'.
                    <br>
                    Русская буква 'Ч' в системе Брайля составлена из точек 1, 2, 3, 4 и 5. 
                    Её можно получить из буквы Г, если дополнить точкой 3.
                    """
        )
        +Show(content.symbols.getValue('Ч'))
        +Info(
            """
                    Теперь ознакомьтесь с буквой Ч в книге Голубиной, в верхней части страницы 26.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Введите по буквам слово ЧЕК"""
        )
        inputPhraseByLetters("ЧЕК")
        +Info(
            """Наберите отдельными буквами слово ОЧКИ"""
        )
        inputPhraseByLetters("ОЧКИ")
        +Info(
            """Далее введите по буквам слово КОЧАН"""
        )
        inputPhraseByLetters("КОЧАН")
        +Info(
            """Введите по буквам ещё одно, последнее слово: БОЧОНОК"""
        )
        inputPhraseByLetters("БОЧОНОК")
        +Info(
            """
                    Запишите на брайлевском приборе изученные слова, разделяя их запятыми:
                    <br>
                    ЧЕК, ОЧКИ, КОЧАН, БОЧОНОК
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson, в котором мы изучали букву 'Ч', позади. 
                    А в следующий раз мы будем заниматься буквой Р.
                    """
        })
    }
    lesson(
        name = "Буква Р"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Р.</b>
                    <br><br>
                    Этому уроку соответствует страницы 27 и 28 пособия.
                    <br>
                    Перед стартом повторим материал прошлых уроков. 
                    Введите по символам слово ПЧЕЛА.
                    """
        })
        inputPhraseByLetters("ПЧЕЛА")
        +Info(
            """
                    Сегодня мы изучим букву 'Р'.
                    <br>
                    Буква 'Р' формируется из точек с номерами 1, 2, 3 и 5. 
                    Иначе говоря, буква Р - это буква Х и точка 3.
                    """
        )
        +Show(content.symbols.getValue('Р'))
        +Info(
            """
                    Раскройте страницу 27 в пособии и ознакомьтесь с буквой Р вверху листа.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Р')
        +Info(
            """Наберите последовательно, по буквам слово РЕКА"""
        )
        inputPhraseByLetters("РЕКА")
        +Info(
            """Наберите отдельными символами слово КРАН"""
        )
        inputPhraseByLetters("КРАН")
        +Info(
            """Далее в четырёх шагах введите по буквам слово КРЕМ"""
        )
        inputPhraseByLetters("КРЕМ")
        +Info(
            """Теперь введите по символам слово ФАРА"""
        )
        inputPhraseByLetters("ФАРА")
        +Info(
            """Наберите аналогичным образом последнее слово в сегодняшнем уроке: ГАРАЖ"""
        )
        inputPhraseByLetters("ГАРАЖ")
        +Info(
            """
                    Возьмите брайлевский прибор и запишите через запятую пройденные слова:
                    <br>
                    РЕКА, КРАН, КРЕМ, ФАРА, ГАРАЖ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson завершён. Теперь мы, помимо прочего, знаем точечный состав буквы 'Р'.
                    За этим уроком следует занятие, посвящённое букве С.
                    """
        })
    }
    lesson(
        name = "Буква С"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква С.</b>
                    <br><br>
                    Перед уроком вспомним старый материал.
                    Введите по буквам слово МАРАФОН
                    """
        })
        inputPhraseByLetters("МАРАФОН")
        +Info(
            """
                    Предмет этого урока - буква 'С'.
                    <br>
                    Буква 'С' в системе Брайля представлена точками 2, 3 и 4.
                    Точками 2 и 4, как вы помните, обозначается буква И. Буква С - это буква И,
                    дополненная точкой номер 3.
                    """
        )
        +Show(content.symbols.getValue('С'))
        +Info(
            """
                    Перейдите в пособии Голубиной к странице 29 и прочтите сверху строку с буквой С.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('С')
        +Info(
            """В следующих шагах наберите слово САЖА"""
        )
        inputPhraseByLetters("САЖА")
        +Info(
            """Наберите по буквам слово СЛЕД"""
        )
        inputPhraseByLetters("СЛЕД")
        +Info(
            """Введите буквы, образующие слово ФАСАД"""
        )
        inputPhraseByLetters("ФАСАД")
        +Info(
            """Введите буквы, которые составляют слово ДОСКА"""
        )
        inputPhraseByLetters("ДОСКА")
        +Info(
            """В завершение урока введите по буквам слово ЧЕСНОК"""
        )
        inputPhraseByLetters("ЧЕСНОК")
        +Info(
            """
                    Осталось немного поработать с брайлевским прибором. Запишите на нём слова:
                    <br>
                    САЖА, СЛЕД, ФАСАД, ДОСКА, ЧЕСНОК
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Мы подошли к финалу урока $iLesson. К этому моменту мы уже изучили 19 букв,
                    знак препинания 'ЗАПЯТАЯ' и цифры. В следующем уроке изучим букву Т.
                    """
        })
    }
    lesson(
        name = "Буква Т и знак 'Дефис'"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Т и знак 'Дефис'.</b>
                    <br><br>
                    Как обычно, предварим урок повторением пройденного.
                    Введите символы, составляющие слово СОЛНЦЕ
                    """
        })
        inputPhraseByLetters("СОЛНЦЕ")
        +Info(
            """Теперь наберите число 870, сначала поставив цифровой знак"""
        )
        inputNumber(870)
        +Info(
            """
                    Теперь рассмотрим букву 'Т'.
                    <br>
                    Буква 'Т' в алфавите Брайля - это точки 2, 3, 4 и 5.
                    Поскольку точками 2, 4 и 5 образована буква Ж, то буква Т - это буква Ж 
                    и ещё точка номер 3.
                    """
        )
        +Show(content.symbols.getValue('Т'))
        +Info(
            """
                    В пособии В. В. Голубиной найдите букву Т на странице 30
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Далее, пожалуйста, введите слово ТЕКСТ"""
        )
        inputPhraseByLetters("ТЕКСТ")
        +Info(
            """Введите по буквам слово ТОРТ"""
        )
        inputPhraseByLetters("ТОРТ")
        +Info(
            """
                    С этого момента мы начинаем осваивать символы, содержащие точку 6.
                    Прямо сейчас перейдём к изучению дефиса.
                    <br>
                    Знак 'Дефис' обозначается точками 3 и 6. Не нужно путать его с буквой Ц: 
                    точки буквы Ц — в верхней трети шеститочия, точки дефиса — в самой нижней.
                    """
        )
        +Show(content.symbols.getValue(Hyphen.c))
        +Info(
            """
                   Переверните страницу в пособии. На странице 31 найдите по центру знак "дефис",
                   повторённый пять раз.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Введите по символам слово ПОЛ-ЛИМОНА"""
        )
        inputPhraseByLetters("ПОЛ${Hyphen.c}ЛИМОНА")
        +Info(
            """И последнее слово, которое нужно ввести в этом уроке — местоимение ГДЕ-ЛИБО"""
        )
        inputPhraseByLetters("ГДЕ${Hyphen.c}ЛИБО")
        +Info(
            """
                    Теперь рекомендуем Вам записать на брайлевском приборе изученные слова:
                    <br>
                    ПОЛ—ЛИМОНА, ГДЕ—ЛИБО
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(
            """
                    На этом урок 14 закончен. Буква Т, которой он был посвящён, стала двадцатой
                    изученной нами. Также мы познакомились со знаком 'дефис'.
                    В следующий раз перейдём к букве У.
                    """
        )
    }
    lesson(
        name = "Буква У"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква У.</b>
                    <br><br>
                    Вспомним для начала материал прошлых уроков.
                    На следующих этапах введите по буквам слово ТЕЛЕФОН
                    """
        })
        inputPhraseByLetters("ТЕЛЕФОН")
        +Info(
            """
                    Начинаем знакомство с буквой У. Эта буква первая в нашем курсе содержит точку 6.
                    <br>
                    Буква 'У' обозначается точками номер 1, 3 и 6.
                    """
        )
        +Show(content.symbols.getValue('У'))
        +Info(
            """
                   В книге Голубиной буква У вводится на странице 32.
                   <br>
                   Откройте эту страницу и прочтите верхнюю строку.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('У')
        +Info(
            """В следующих шагах введите, пожалуйста, слово УГОЛ"""
        )
        inputPhraseByLetters("УГОЛ")
        +Info(
            """Наберите, последовательно вводя буквы, слово ЛУНА"""
        )
        inputPhraseByLetters("ЛУНА")
        +Info(
            """Введите буквы, формирующие слово КРУГ"""
        )
        inputPhraseByLetters("КРУГ")
        +Info(
            """Введите буквы, которые бы составили слово ТРУД"""
        )
        inputPhraseByLetters("ТРУД")
        +Info(
            """Последнее, что нужно набрать в этом уроке — слово ЧУДЕСА"""
        )
        inputPhraseByLetters("ЧУДЕСА")
        +Info(
            """
                    Набранные в этом уроке слова запишем и на брайлевском приборе через запятую:
                    <br>
                    УГОЛ, ЛУНА, КРУГ, ТРУД, ЧУДЕСА
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson окончен. Мы изучили букву У — первую букву, где нам встретилась точка
                    номер 6 (но не первый символ: ранее мы сталкивались с ним, изучая цифровой знак
                    и знак 'Дефис'). В следующем занятии нас ждёт буква Щ.
                    """
        })
    }
    lesson(
        name = "Буква Щ"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Щ.</b>
                    <br><br>
                    В виде разминки повторим ранее изученное.
                    Введите буквы, которые сложатся в слово ХУДОЖНИК
                    """
        })
        inputPhraseByLetters("ХУДОЖНИК")
        +Info(
            """
                    Ознакомимся с буквой Щ.
                    <br>
                    Буква 'Щ' состоит из четырёх точек с номерами 1, 3, 4 и 6. Как буква Ц
                    и знак дефиса в одной клеточке.
                    """
        )
        +Show(content.symbols.getValue('Щ'))
        slateStylusLine('Щ')
        +Info(
            """
                   Пособие содержит урок с буквой Щ на странице 33.
                   <br>
                   Найдите эту страницу и изучите самую верхнюю строку.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Вводя букву за буквой, составьте слово ЩЕГОЛ"""
        )
        inputPhraseByLetters("ЩЕГОЛ")
        +Info(
            """Теперь наберите, пожалуйста, слово ПЛАЩ"""
        )
        inputPhraseByLetters("ПЛАЩ")
        +Info(
            """Наберите отдельными буквами слово КЛЕЩ"""
        )
        inputPhraseByLetters("КЛЕЩ")
        +Info(
            """Наберите буквы, которые бы составили слово ЩЕПКА"""
        )
        inputPhraseByLetters("ЩЕПКА")
        +Info(
            """И последнее: введите слово ОЩУЩЕНИЕ"""
        )
        inputPhraseByLetters("ОЩУЩЕНИЕ")
        +Info(
            """
                    Перед тем, как мы закончим занятие, запишите на брайлевском приборе все пройденные слова:
                    <br>
                    ЩЕГОЛ, ПЛАЩ, КЛЕЩ, ЩЕПКА, ОЩУЩЕНИЕ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson - буква Щ - подходит к завершению. Теперь нам известны 22 буквы русского
                    алфавита. Следующее занятие будет на тему буквы З.
                    """
        })
    }
    lesson(
        name = "Буква З"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква З.</b>
                    <br><br>
                    Новый материал мы будем изучать после краткого повторения.
                    Далее введите буквы слова ЩЕПОТКА
                    """
        })
        inputPhraseByLetters("ЩЕПОТКА")
        +Info(
            """
                    Новая буква, которую нам надо изучить - З.
                    <br>
                    Буква 'З' образована точками 1, 3, 5 и 6. Её можно составить, соединив в одной
                    клетке букву Е и знак 'дефис'.
                    """
        )
        +Show(content.symbols.getValue('З'))
        +Info(
            """
                   В книге Голубиной букву З можно найти на странице 34.<br>
                   Прочтите первую строку на этой странице.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('З')
        +Info(
            """Последовательно, по буквам введите слово ЗАКАЗ"""
        )
        inputPhraseByLetters("ЗАКАЗ")
        +Info(
            """Теперь из отдельных букв наберите слово ЗЕРНО"""
        )
        inputPhraseByLetters("ЗЕРНО")
        +Info(
            """Наберите по буквам очень важное для нас слово АЗБУКА"""
        )
        inputPhraseByLetters("АЗБУКА")
        +Info(
            """В следующих пяти шагах введите слово АРБУЗ"""
        )
        inputPhraseByLetters("АРБУЗ")
        +Info(
            """И последнее, что сегодня осталось ввести: слово ЗАДАЧА"""
        )
        inputPhraseByLetters("ЗАДАЧА")
        +Info(
            """
                    Для закрепления материала напишите слова на брайлевском приборе:
                    <br>
                    ЗАКАЗ, ЗЕРНО, АЗБУКА, АРБУЗ, ЗАДАЧА
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    Вы успешно окончили урок $iLesson - буква З. На следующем занятии перейдём к освоению
                    буквы И краткое.
                    """
        })
    }
    lesson(
        name = "Буква Й"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква "И краткое".</b>
                    <br><br>
                    Знакомство с новой буквой начнём после небольшой ревизии ранее пройденного.
                    Пожалуйста, введите буквы, образующие слово МИМОЗА
                    """
        })
        inputPhraseByLetters("МИМОЗА")
        +Info(
            """Также в качестве повторения введите цифровой знак, а за ним число 964"""
        )
        inputNumber(964)
        +Info(
            """
                    Переходим к главному в сегодняшнем уроке: ознакомимся с буквой 'И краткое'.
                    <br>
                    Буква 'Й' обозначается пятью точками с номерами 1, 2, 3, 4 и 6, 
                    до полного шеститочия не хватает лишь точки 5. Букву 'Й' можно получить из буквы
                    П, добавив точку номер 6.
                    """
        )
        +Show(content.symbols.getValue('Й'))
        +Info(
            """
                   Пособие под редакцией В. Голубиной содержит материал на тему буквы Й на странице 35.
                   <br>
                   Ознакомьтесь с рельефно-графическим и рельефно-точечным изображением буквы "Й" на первой строке.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Й')
        +Info(
            """Буква за буквой, введите точечным шрифтом слово КЛЕЙ"""
        )
        inputPhraseByLetters("КЛЕЙ")
        +Info(
            """Введите отдельными символами второе слово с буквой Й: УЛЕЙ"""
        )
        inputPhraseByLetters("УЛЕЙ")
        +Info(
            """Наберите, пожалуйста, по буквам слово РЕЙС"""
        )
        inputPhraseByLetters("РЕЙС")
        +Info(
            """Осталось ещё два задания. В следующих четырёх шагах введите слово ЗНОЙ"""
        )
        inputPhraseByLetters("ЗНОЙ")
        +Info(
            """Наконец, введите последнее слово в этом уроке: РАЙОН"""
        )
        inputPhraseByLetters("РАЙОН")
        +Info(
            """
                    Все пройденные слова следует записать на брайлевском приборе. Напомним, это слова
                    <br>
                    КЛЕЙ, УЛЕЙ, РЕЙС, ЗНОЙ, РАЙОН
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    Урок $iLesson - буква 'И краткое' - окончен. Теперь мы знаем уже 4 буквы, содержащие
                    точку номер 6. Предлагаем Вам самостоятельно вспомнить, какие именно.
                    <br>
                    До встречи на следующем уроке, где мы будем изучать твёрдый знак и 
                    знак препинания 'Литературная точка'.
                    """
        })
    }
    lesson(
        name = "Твёрдый знак и литературная точка"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Твёрдый знак и литературная точка.</b>
                    <br><br>
                    Вначале повторим ранее изученные буквы.
                    Введите по буквам прилагательное ОСЕННИЙ
                    """
        })
        inputPhraseByLetters("ОСЕННИЙ")
        +Info(
            """
                    Мы готовы к изучению твёрдого знака.
                    <br>
                    Твёрдый знак - это точки 1, 2, 3, 5 и 6. Почти полное шеститочие, нет только
                    точки номер 4. Твёрдый знак получается из буквы 'Р' добавлением точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ъ'))
        +Info(
            """
                   Откройте раздел пособия, где изучается твёрдый знак, на странице 36.
                   <br>
                   Прочтите верхнюю строку, которая содержит пять повторов этого символа.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ъ')
        +Info(
            """Введите по буквам слово СЪЕЗД"""
        )
        inputPhraseByLetters("СЪЕЗД")
        +Info(
            """Символ за символом, наберите слово СУБЪЕКТ"""
        )
        inputPhraseByLetters("СУБЪЕКТ")
        +Info(
            """
                    Теперь постараемся запомнить обозначение литературной точки.
                    <br>
                    Знак препинания 'Литературная точка' образован в системе Брайля точками 2, 5 и 6.
                    Не следует путать его с буквой Д.
                    """
        )
        +Show(content.symbols.getValue('.'))
        +Info(
            """
                   В середине страницы 36 пособия, где мы изучали твёрдый знак, найдите и прочтите
                   строку с изображением литературной точки.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Input(content.symbols.getValue('.'))
        +Info(
            "Используя брайлевский прибор, запишите строку из одних точек."
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(
            """
                    В следующих шагах введите по буквам целое предложение: "Ленинград — город-герой".
                    <br>
                    В конце поставьте литературную точку.
                    """
        )
        inputPhraseByLetters("ЛЕНИНГРАД${Hyphen.c}ГОРОД${Hyphen.c}ГЕРОЙ.")
        +Info(
            """
                    Теперь запишите на брайлевском приборе то же самое предложение:
                    <br>
                    ЛЕНИНГРАД — ГОРОД—ГЕРОЙ.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    На этом мы завершаем занятие номер $iLesson. Осталось ещё семь уроков, после чего 
                    мы будем знать все русские буквы. В следующем уроке узнаем точечный состав
                    буквы Ы.
                    """
        })
    }
    lesson(
        name = "Буква Ы"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква Ы.</b>
                    <br><br>
                    Ради закрепления пройденного введите по символам слово ОБЪЕДИНЕНИЕ
                    """
        })
        inputPhraseByLetters("ОБЪЕДИНЕНИЕ")
        +Info(
            """Также повторим специальные символы.
                    Введите цифровой знак, запятую, дефис и точку"""
        )
        +Input(content.markers.getValue(MarkerType.NumberSign))
        inputChars(",${Hyphen.c}.")
        +Info(
            """
                    Переходим к изучению точечного состава буквы Ы.
                    <br>
                    Буква Ы представлена точками с номерами 2, 3, 4 и 6. Как несложно заметить,
                    букву Ы можно получить добавлением точки номер 6 к букве С.
                    """
        )
        +Show(content.symbols.getValue('Ы'))
        +Info(
            """
                   Теперь посетим страницу 37 пособия, где нужно найти и прочесть верхнюю строку - 
                   рельефно-графические и рельефно-точечное изображение буквы Ы.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ы')
        +Info(
            """Набирая буквы одна за одной, введите слово МЫЛО"""
        )
        inputPhraseByLetters("МЫЛО")
        +Info(
            """Далее введите ещё одно слово по буквам: ЛЫЖИ"""
        )
        inputPhraseByLetters("ЛЫЖИ")
        +Info(
            """Теперь введите буквы, из которых складывается слово КЛЫК"""
        )
        inputPhraseByLetters("КЛЫК")
        +Info(
            """Наберите предпоследнее слово в этом уроке - слово МУЗЫКА"""
        )
        inputPhraseByLetters("МУЗЫКА")
        +Info(
            """Введите последнее слово - существительное во множественном числе: КОЗЫ"""
        )
        inputPhraseByLetters("КОЗЫ")
        +Info(
            """
                    Все изученные слова, пожалуйста, запишите и на брайлевском приборе:
                    <br>
                    МЫЛО, ЛЫЖИ, КЛЫК, МУЗЫКА, КОЗЫ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    Урок $iLesson - буква 'Ы' - подходит к завершению.
                    Остались неизученными семь букв русского алфавита; для них отведены последующие
                    шесть уроков. На следующем занятии будем осваивать мягкий знак.
                    """
        })
    }
    lesson(
        name = "Мягкий знак"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Мягкий знак.</b>
                    <br><br>
                    Как и в прошлые разы, перед занятием повторим ранее изученное.
                    Введите, набирая отдельные буквы, прилагательное РЫЖИЙ
                    """
        })
        inputPhraseByLetters("РЫЖИЙ")
        +Info(
            """
                    Два урока назад мы изучали твёрдый знак, а теперь освоим и мягкий знак тоже.
                    <br>
                    Мягкий знак обозначается точками 2, 3, 4, 5 и 6. Он получается из буквы Т и
                    точки номер 6.
                    """
        )
        +Show(content.symbols.getValue('Ь'))
        +Info(
            """
                   Откройте страницу 39 в пособии Голубиной. Изучите первую строку, где содержится
                   мягкий знак.
                   <br>
                   После урока рекомендуем прочесть слова на страницах 39 и 40.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ь')
        +Info(
            """Введите по буквам существительное СОЛЬ"""
        )
        inputPhraseByLetters("СОЛЬ")
        +Info(
            """Теперь нужно ввести слово МЕЛЬ"""
        )
        inputPhraseByLetters("МЕЛЬ")
        +Info(
            """Далее, пожалуйста, составьте из букв слово КОНЬ"""
        )
        inputPhraseByLetters("КОНЬ")
        +Info(
            """Осталось ввести два слова.
                    Первое - существительное во множественном числе: РУЧЬИ"""
        )
        inputPhraseByLetters("РУЧЬИ")
        +Info(
            """Введите последнее в этом занятии слово: СТАЛЬ"""
        )
        inputPhraseByLetters("СТАЛЬ")
        +Info(
            """
                    Как обычно, напишите на брайлевском приборе изученные слова:
                    <br>
                    СОЛЬ, МЕЛЬ, КОНЬ, РУЧЬИ, СТАЛЬ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    Урок $iLesson, в котором мы изучили мягкий знак, пройден.
                    В течение следующего занятия мы изучим сразу две буквы: Ё и Ш.
                    """
        })
    }
    lesson(
        name = "Буквы Ё и Ш"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буквы Ё и Ш.</b>
                    <br><br>
                    Перед уроком будет полезно вспомнить буквы, пройденные на прошлых занятиях.
                    Введите шаг за шагом слово АПЕЛЬСИН
                    """
        })
        inputPhraseByLetters("АПЕЛЬСИН")
        +Info(
            """
                    Теперь приступим к изучению буквы, которая сравнительно недавно появилась 
                    в русском языке - буквы Ё.
                    <br>
                    Буква 'Ё' обозначается двумя точками с номерами 1 и 6. Она получается из буквы А
                    добавлением точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ё'))
        +Info(
            """
                   Вводный текст о буквах Ё и Ш можно найти в пособии на страницах 41 и 42.
                   <br>
                   Откройте страницу 41 и прочтите верхнюю строку с буквой Ё.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ё')
        +Info(
            """Шаг за шагом введите слово ЁЛКА"""
        )
        inputPhraseByLetters("ЁЛКА")
        +Info(
            """Введите далее название имя ещё одного дерева - КЛЁН"""
        )
        inputPhraseByLetters("КЛЁН")
        +Info(
            """
                    Теперь давайте посмотрим на букву Ш.
                    <br>
                    Буква 'Ш' формируется из точек номер 1, 5 и 6. Её можно получить, приписав к 
                    букве Е точку 6.
                    """
        )
        +Show(content.symbols.getValue('Ш'))
        +Info(
            """
                   Прочтите строку с буквой Ш в середине страницы 41 пособия.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ш')
        +Info(
            """Наберите отдельными символами слово ШЁЛК"""
        )
        inputPhraseByLetters("ШЁЛК")
        +Info(
            """Теперь введите буквы, которые вместе складываются в слово ШЕСТ"""
        )
        inputPhraseByLetters("ШЕСТ")
        +Info(
            """Введите предпоследнее слово в нашем уроке, слово ШАРФ"""
        )
        inputPhraseByLetters("ШАРФ")
        +Info(
            """Наконец, перед тем, как мы закончим урок, введите слово КОШКА"""
        )
        inputPhraseByLetters("КОШКА")
        +Info(
            """
                    Используя брайлевский прибор, запишите изученные в этом уроке существительные:
                    <br>
                    ЁЛКА, КЛЁН, ШЁЛК, ШЕСТ, ШАРФ, КОШКА
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """                    
                    Урок $iLesson, посвящённый буквам Ё и Ш, завершён.
                    <br>
                    До окончания изучения всего алфавита осталось 4 урока и 4 буквы: В, Э, Ю, Я.
                    В следующем уроке введём букву Я.
                    """
        })
    }
    lesson(
        name = "Буква Я"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква 'Я'.</b>
                    <br><br>
                    Мы выучили уже много букв, и перед занятием повторим часть из них.
                    Введите по буквам слово МИШЕНЬ
                    """
        })
        inputPhraseByLetters("МИШЕНЬ")
        +Info(
            """
                    Познакомимся с точечным составом буквы, последней в русском алфавите, 
                    но не в нашем курсе - с буквой Я.
                    <br>
                    Буква 'Я' - это точки 1, 2, 4 и 6. Иначе говоря, эта буква составлена из точек
                    буквы 'Ф' и точки 6 в одной клетке.
                    """
        )
        +Show(content.symbols.getValue('Я'))
        +Info(
            """
                   Изучению буквы 'Я' отведены страницы 43 и 44 в пособии под редакцией В. Голубиной.
                   <br>
                   Откройте страницу 43 и прочтите верхнюю строку - пять букв 'Я' подряд.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Я')
        +Info(
            """Введите брайлевские буквы, которые составляют слово ЯБЛОКО"""
        )
        inputPhraseByLetters("ЯБЛОКО")
        +Info(
            """В следующих пяти шагах нужно ввести слово ЯГОДА"""
        )
        inputPhraseByLetters("ЯГОДА")
        +Info(
            """Далее, пожалуйста, наберите отдельными буквами слово ПЯТНО"""
        )
        inputPhraseByLetters("ПЯТНО")
        +Info(
            """Ещё два слова нужно ввести в этом уроке.
                    <br>
                    Первое - название птицы: ЦАПЛЯ"""
        )
        inputPhraseByLetters("ЦАПЛЯ")
        +Info(
            """Последнее слово в сегодняшнем уроке - ЗЕМЛЯ"""
        )
        inputPhraseByLetters("ЗЕМЛЯ")
        +Info(
            """
                    Запишите на брайлевском приборе изученные слова с буквой Я:
                    <br>
                    ЯБЛОКО, ЯГОДА, ПЯТНО, ЦАПЛЯ, ЗЕМЛЯ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson - буква Я - успешно завершён.
                    В следующий раз мы будем осваивать букву Ю.
                    """
        })
    }
    lesson(
        name = "Буква Ю"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква 'Ю'.</b>
                    <br><br>
                    Начнём с ревизии уже изученных букв и специальных символов.
                    Введите, набирая отдельные буквы, слово ПОЛЯНА и поставьте после него запятую
                    """
        })
        inputPhraseByLetters("ПОЛЯНА,")
        +Info(
            """
                    В этом уроке нам надо познакомиться с буквой Ю.
                    <br>
                    Буква 'Ю' обозначается четырьмя точками: 1, 2, 5 и 6. Иначе, она составлена из
                    буквы Х и дополнительной точки 6.
                    """
        )
        +Show(content.symbols.getValue('Ю'))
        +Info(
            """
                   Буква 'Ю' и слова с ней находятся на страницах 45 и 46 в пособии. 
                   <br>
                   Найдите сорок пятую страницу и ознакомьтесь с буквой Ю в самой верхней строке.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Ю')
        +Info(
            """Наберите по символам слово с новой буквой: ЮБКА"""
        )
        inputPhraseByLetters("ЮБКА")
        +Info(
            """В следующих четырёх шагах наберите слово УТЮГ"""
        )
        inputPhraseByLetters("УТЮГ")
        +Info(
            """Заметьте, что буква Т и буква Ю получаются друг из друга отражением 
                    по вертикали. 
                    <br>
                    После этого шага, пожалуйста, введите по буквам слово ТЮБИК"""
        )
        inputPhraseByLetters("ТЮБИК")
        +Info(
            """Нам осталось выполнить два задания, после чего урок заканчивается.
                    <br>
                    Первое: введите слово ТРЮК"""
        )
        inputPhraseByLetters("ТРЮК")
        +Info(
            """Завершающее задание в этом уроке - введите буквы слова СЮЖЕТ"""
        )
        inputPhraseByLetters("СЮЖЕТ")
        +Info(
            """
                    Снова возьмите брайлевский прибор и напишите пройденные слова с буквами Ю, Т:
                    <br>
                    ЮБКА, УТЮГ, ТЮБИК, ТРЮК, СЮЖЕТ
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson - русская буква Ю - закончен. Нам осталось пройти всего два занятия,
                    после чего весь алфавит будет изучен.
                    <br>
                    В нашей предпоследней встрече, связанной с русским алфавитом, мы освоим букву Э.
                    """
        })
    }
    lesson(
        name = "Буква Э"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква 'Э'.</b>
                    <br><br>
                    Перед погружением в новый материал повторим пройденное.
                    Введите по буквам слово ИНТЕРЕСНЫЙ
                    """
        })
        inputPhraseByLetters("ИНТЕРЕСНЫЙ")
        +Info(
            """Ещё перед началом урока мы чуть-чуть повторим числа. Введите цифровой знак и
                    за ним число 1984
                    """
        )
        inputNumber(1984)
        +Info(
            """
                    Давайте изучим букву 'Э'.
                    <br>
                    Буква 'Э' представлена комбинацией трёх точек: 2, 4 и 6. Она составлена из буквы
                    'И' плюс точка 6.
                    """
        )
        +Show(content.symbols.getValue('Э'))
        +Info(
            """
                   Для развития памяти пальцев рекомендуется в дополнение к этому уроку
                   просмотреть материал о букве Э на страницах 47 и 48 в пособии. 
                   <br>
                   Сейчас откройте страницу 47 и прочтите первую строку, где написана буква 'Э'.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('Э')
        +Info(
            """Вводя отдельные буквы, составьте слово ЭХО"""
        )
        inputPhraseByLetters("ЭХО")
        +Info(
            """Обратите внимание, буква 'Э' образуется зеркальным отражением буквы 'О'
                    вдоль вертикальной оси.
                    <br>
                    В следующих пяти шагах наберите по буквам слово ПОЭМА"""
        )
        inputPhraseByLetters("ПОЭМА")
        +Info(
            """Теперь мы попросим Вас ввести слово ЭКРАН"""
        )
        inputPhraseByLetters("ЭКРАН")
        +Info(
            """
                    В этом уроке ещё два задания на ввод слов.
                    <br>
                    Первое из них: составьте слово ЭПИЗОД"""
        )
        inputPhraseByLetters("ЭПИЗОД")
        +Info(
            """В последнем задании нужно ввести слово ЭСТРАДА"""
        )
        inputPhraseByLetters("ЭСТРАДА")
        +Info(
            """
                    Теперь запишите введённые ранее слова на брайлевском приборе:
                    <br>
                    ЭХО, ПОЭМА, ЭКРАН, ЭПИЗОД, ЭСТРАДА
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                    Урок $iLesson, в ходе которого мы выучили букву Э, закончен.
                    <br>
                    В следующем уроке изучим букву В, после чего весь алфавит будет освоен.
                    """
        })
    }
    lesson(
        name = "Буква В"
    ) {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Буква 'В'.</b>
                    <br><br>
                    В начале этого занятия вспомним материал, ранее пройденный в курсе.
                    Пожалуйста, наберите буквы, составляющие слово ЭНЦИКЛОПЕДИЯ
                    """
        })
        inputPhraseByLetters("ЭНЦИКЛОПЕДИЯ")
        +Info(
            """
                    Изучим последнюю букву, которую мы пока не рассматривали - букву 'В'.
                    <br>
                    Буква 'В' в системе Брайля - это комбинация четырёх точек: 2, 4, 5 и 6. Её можно
                    составить, написав букву 'Ж' и добавив точку номер 6 в той же клетке. 
                    """
        )
        +Show(content.symbols.getValue('В'))
        +Info(
            """
                    Для более тщательного изучения буквы 'В' мы рекомендуем обратиться к пособию В.
                    Голубиной, страницы 49 и 50.
                    <br>
                    В данный момент предлагаем Вам раскрыть страницу 49 и прочесть верхнюю строку,
                    где написана буква 'В'.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        slateStylusLine('В')
        +Info(
            """Наберите первое слово с буквой 'В' - слово ВОР"""
        )
        inputPhraseByLetters("ВОР")
        +Info(
            """Мы не случайно привели слово, содержащее буквы 'В' и 'Р'. Обратите внимание, что
                    каждая из них получается зеркальным отражением другой по вертикали.
                    <br>
                    Далее введите по символам слово ВРАЧ"""
        )
        inputPhraseByLetters("ВРАЧ")
        +Info(
            """В следующих шести шагах введите, пожалуйста, буквы слова ВОРОНА"""
        )
        inputPhraseByLetters("ВОРОНА")
        +Info(
            """
                    Нужно составить ещё два слова.
                    <br>
                    Введите по буквам слово СЕВЕР"""
        )
        inputPhraseByLetters("СЕВЕР")
        +Info(
            """Заключительное упражнение: наберите слово КОРОВА"""
        )
        inputPhraseByLetters("КОРОВА")
        +Info(
            """
                    Не забудьте для тренировки написать на брайлевском приборе набранные слова:
                    <br>
                    ВОР, ВРАЧ, ВОРОНА, СЕВЕР, КОРОВА.
            """
        ).annotate(StepAnnotation.slateStylusRequired)
        +Info(InfoInterpolation.run {
            """
                Урок $iLesson - буква В - закончен.
                <br>
                Теперь Вам знаком весь русский алфавит и цифры, а также некоторые знаки препинания.
                В следующих занятиях мы пополним наш запас знаков препинания.
            """
        })
    }
    lesson("Двоеточие и точка с запятой") { // Golubina pp 53-54
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: Двоеточие и точка с запятой.</b>
                <br><br>
                До сих пор мы знали три знака препинания - точка, запятая и дефис (тире).
                В этом уроке будут введены ещё два.
                <br>
                В виде разминки перед уроком введите по буквам слово ДВОЕТОЧИЕ
                """
        })
        inputPhraseByLetters("ДВОЕТОЧИЕ")
        +Info(
            """
                    В рельефно-точечном алфавите точка с запятой обозначается точками с номерами 2
                    и 3. Напоминает букву Б, только точки сдвинуты на ряд вниз.
                    <br>
                    В следующих шагах ознакомьтесь с символом "Точка с запятой".
                    """
        )
        showAndInputChars(";")
        +Info(
            """
                    Раскройте пособие В. Голубиной на странице 53.
                    <br>
                    Прочтите шестую сверху строку, где после полного шеститочия приведено обозначение
                    знака "точка с запятой". Затем прочтите цитату М. Шолохова в строках ниже.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """
                    Точка с запятой используется для разделения частей сложного предложения.
                    <br>
                    В следующих шагах введите слово РАЗДЕЛЕНИЕ; и поставьте в конце точку с запятой.
            """
        )
        inputPhraseByLetters("РАЗДЕЛЕНИЕ;")
        +Info(
            """
                    Двоеточие записывается в системе Брайля с помощью точек 2 и 5. Похоже на дефис,
                    но точки расположены на ряд выше.
                    <br>
                    Далее прочтите, а затем введите этот знак.
                    """
        )
        showAndInputChars(":")
        +Info(
            """
                    В пособии В. В. Голубиной перейдите к странице 54.
                    <br>
                    На этой странице прочтите строку 4 сверху, где записан брайлевский знак двоеточия.
                    <br>
                    Прочтите и остальное содержание страницы 54 - предложение о Летнем Саде, а также
                    цитаты Пушкина и Горького.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Введите по буквам слово ВЫВОД: и поставьте в конце двоеточие"""
        )
        inputPhraseByLetters("ВЫВОД:")
        +Info(
            """
                    Перепишите, используя брайлевский прибор, предложение со страницы 54 пособия:
                    <br>
                    <b>Летний Сад омывается реками: Невой, Мойкой, Фонтанкой и Лебяжьей Канавкой.</b>
            """
        ).annotate(StepAnnotation.slateStylusRequired, StepAnnotation.golubinaBookRequired)
        +Info(InfoInterpolation.run {
            """
                Урок $iLesson - двоеточие и точка с запятой - подошёл к концу.
                <br>
                Следующий урок посвящён не менее важным символам - вопросительному знаку и 
                восклицательному знаку.
                """
        })
    }
    lesson("Вопросительный и восклицательный знак") {
        +Info(InfoInterpolation.run {
            """
                    <b>Урок $iLesson. Вопросительный и восклицательный знак.</b>
                    <br><br>
                    В этом уроке мы пополним коллекцию известных нам знаков препинания.
                    <br>
                    Перед стартом немного повторения. Введите слово <b>"ВОСКЛИЦАНИЕ"</b>
                    """
        })
        inputPhraseByLetters("ВОСКЛИЦАНИЕ")
        +Info(
            """
                    Вопросительный знак - точки 2 и 6. Как буква Е, но точки сдвинуты на один ряд вниз.
                    <br>
                    В следующих шагах ознакомимся с этим символом.
                    """
        )
        showAndInputChars("?")
        +Info(
            """
                    Раскройте страницу 55 пособия.
                    <br>
                    В четвёртой снизу строчке вводится вопросительный знак. Полное шеститочие перед
                    ним приведено лишь в качестве ориентира.
                    <br>
                    В строках ниже прочтите примеры с вопросительным знаком.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """Введите вопрос: ГДЕ?"""
        )
        inputPhraseByLetters("ГДЕ?")
        +Info("""Наберите по буквам вопрос: КОГДА?""")
        inputPhraseByLetters("КОГДА?")

        +Info(
            """
                    Восклицательный знак в системе Брайля - точки 2, 3 и 5. Не перепутайте с буквой Ф:
                    точки расположены похожим образом, но каждая сдвинута на ряд ниже.
                    """
        )
        showAndInputChars("!")
        +Info(
            """
                    Найдите в обучающем пособии страницу 56.
                    <br>
                    В третьей сверху строке описан восклицательный знак. Прочтите эту строку.
                    <br>
                    Затем прочтите приведённые в следующих строках цитаты А. С. Пушкина и Н. А. 
                    Некрасова.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info("""В завершение урока введите слово с восклицательным знаком на конце: ЧУДЕСНО!""")
        inputPhraseByLetters("ЧУДЕСНО!")
        +Info(InfoInterpolation.run {
            """
                Поздравляем. Урок $iLesson - восклицательный и вопросительный знак - завершён.
                <br>
                В следующем уроке мы изучим скобки, кавычки и знак "Звёздочка".
            """
        })
    }
    lesson("""Скобки, кавычки и знак "*" """) { // Golubina pp 57-58
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: Скобки, кавычки и знак "Звёздочка".</b>
                <br><br>
                В результате этого занятия мы изучим парные знаки препинания - скобки и кавычки,
                а также узнаем, как в рельефно-точечном алфавите обозначается символ "Звёздочка".
                <br>
                Перед уроком закрепим пройденное. Введите слово <b>"ВНИМАНИЕ!"</b> и поставьте на конце
                восклицательный знак.
                """
        })
        inputPhraseByLetters("ВНИМАНИЕ!")
        +Info(
            """
                    Левая открывающая скобка обозначается точками с номерами 1, 2 и 6, правая - 3,
                    4 и 5. Заметьте, правая является зеркальным отражением левой.
                    <br>
                    Скобки при письме примыкают к выделяемой части предложения.
                    """
        )
        showAndInputChars("()")
        +Info(
            """
                    Найдите страницу 57 в обучающем пособии.
                    <br>
                    Изучите три верхние строки - обозначение скобок и комментарий. Также прочтите
                    на следующих трёх строках предложение о Русском музее с примером употребления
                    скобок.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info("""Введите слово <b>(ВЕРОЯТНО)</b>, заключив его в скобки""")
        inputPhraseByLetters("(ВЕРОЯТНО)")
        +Info(
            """
                    Теперь изучим кавычки. Левая (открывающая) кавычка - это точки 2, 3 и 6, правая
                    (закрывающая) - точки 3, 5 и 6.
                    <br>
                    Как и скобки, кавычки примыкают к выделяемой части. Открывающая и закрывающая
                    кавычки являются зеркальным отражением друг друга.
                    """
        )
        showAndInputChars("«»")
        +Info("""Введите название повести Тургенева - <b>«НАКАНУНЕ»</b>, заключив его в кавычки""")
        inputPhraseByLetters("«НАКАНУНЕ»")
        +Info(
            """
                    Нам осталось изучить ещё один символ в этом уроке - знак "Звёздочка".
                    <br>
                    Звёздочка обозначается двумя точками с номерами 3 и 5.
                    """
        )
        showAndInputChars("*")
        +Info(
            """
                    На той же странице 57 пособия, где мы изучали скобки, прочтите шесть нижних строк.
                    В них демонстрируются символы открывающей скобки, звёздочки и закрывающей скобки.
                    <br>
                    После этого переверните страницу и прочтите шесть верхних строк, где приведены 
                    примеры использования кавычек.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(InfoInterpolation.run {
            """
                Урок $iLesson - cкобки, кавычки и знак "Звёздочка" - подходит к завершению.
                <br>
                Следующие уроки покрывают материал, который встречается в брайлевских книгах 
                не так часто, поэтому упражнений будет меньше и изложение будет носить скорее 
                справочный характер.
                """
        })
    }
    lesson("Специальные символы") { // Golubina: pp 59-62
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: Специальные символы.</b>
                <br><br>
                Этот урок посвящён литературным знакам и знакам выделения шрифтов, которые,
                за исключением, разве что, знака ударения, не имеют аналогов в плоскопечатном
                письме.
                <br>
                До сих пор мы знали один такой знак - цифровой. Теперь познакомимся и с остальными.
                """
        })
        +Info(
            """
                    <b>Знак ударения</b> обозначается точкой 4 и ставится в клетке перед ударной гласной. 
                    <br>
                    Например, в слове <b>МОСКВА</b> знак ударения будет стоять перед буквой А.
                    """
        )
        showAndInputChars("\'")
        +Info(
            """
                    Раскройте пособие В. Голубиной на странице 59.
                    <br>
                    Прочтите вторую сверху строку, где вводится знак ударения. Также прочтите
                    примеры употребления этого знака в шестой и седьмой строках сверху.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """
                    В брайлевских текстах перед именами и названиями иногда ставят <b>признак
                    большой буквы</b>. Он обозначается точками 4 и 5.
                    """
        )
        +Show(content.markers.getValue(MarkerType.RussianCapital))
        +Input(content.markers.getValue(MarkerType.RussianCapital))
        +Info(
            """
                    На странице 59 в пособии прочтите четыре нижние строки, где приводится признак
                    большой русской буквы и предложение с его использованием.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """
                    Если в текст на русском языке вставлено слово на латинице (например, 
                    на английском), перед ним непременно ставится <b>признак большой латинской буквы</b>
                    или <b>признак малой латинской буквы</b>.
                    <br>
                    Признак большой буквы латинского алфавита - точки 4 и 6.
                    <br>
                    Признак малой буквы латинского алфавита обозначается одной точкой номер 6.
                    """
        )
        +Show(content.markers.getValue(MarkerType.LatinCapital))
        +Input(content.markers.getValue(MarkerType.LatinCapital))
        +Info(
            """
                    Перед греческими буквами в русских текстах ставят <b>признак большой буквы
                    греческого алфавита</b>. Он обозначается точками 4, 5 и 6. Не перепутайте 
                    с буквой "Л".
                    """
        )
        +Info(
            """
                    Переверните страницу в пособии и прочтите содержание страницы 60, где вводятся
                    признаки букв греческого и латинского алфавита.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(
            """
                    Иногда для смыслового выделения используют жирный или курсивный шрифт. Для них
                    в брайлевских текстах есть специальные знаки, которые ставятся с обеих сторон
                    выделяемого слова или фразы, причём примыкают вплотную к тексту, как скобки
                    или кавычки.
                    <br>
                    <b>Знак курсивного шрифта</b> обозначается точками 4, 5, 6 (совпадает с признаком большой
                    латинской буквы).
                    <br>
                    <b>Знак жирного шрифта</b> - точки 1, 2, 4, 5, 6 (то есть все, кроме третьей).
                    """
        )
        +Show(content.markers.getValue(MarkerType.ItalicFont))
        +Input(content.markers.getValue(MarkerType.ItalicFont))
        +Show(content.markers.getValue(MarkerType.BoldFont))
        +Input(content.markers.getValue(MarkerType.BoldFont))
        +Info(
            """
                    Прочтите первые пять строк на странице 61. Там рассказывается о знаках жирного
                    и курсивного шрифта. При желании прочтите и остальной материал на странице, где
                    рассказывается о знаках разрядки и выделения врезки. Мы не будем изучать эти знаки
                    в данном курсе.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Info(InfoInterpolation.run {
            """
                Урок $iLesson - специальные символы - закончен.
                <br>
                Мы привели лишь наиболее часто употребимые литературные знаки. Полный
                список доступен в интернете на сайте <b>chtenie.spb.ru/komissia.htm</b>
                <br>
                На следующем занятии мы познакомимся с обозначениями основных арифметических знаков.
                """
        })
    }

    lesson("Математические символы") { // Golubina: p 65
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: Математические символы.</b>
                <br><br>
                В данном уроке мы изучим запись арифметических операций: сложение, умножение,
                вычитание и деление, а также равенство. В плоскопечатном шрифте для умножения и 
                деления есть два варианта записи; оба варианта имеют аналоги в шрифте Брайля.
                <br>
                В следующих шагах ознакомьтесь с обозначениями знаков арифметических действий
                и введите их на экране.
                """
        })
        showAndInputChars("+-✕·/÷=")
        +Info(
            """
                    Раскройте книгу В. В. Голубиной на странице 65 и прочтите её содержание. Там
                    приведены обозначения арифметических операций, математические скобки (здесь мы
                    не будем их изучать) и записано несколько арифметических примеров.
            """
        ).annotate(StepAnnotation.golubinaBookRequired)

        +Info("""В следующих шагах запишите: ДВА ПЛЮС ДВА РАВНО ЧЕТЫРЕ""")
        inputNumber(2)
        +Input(content.symbols.getValue('+'))
        inputNumber(2)
        +Input(content.symbols.getValue('='))
        inputNumber(4)
        +Info(
            """
                    Запишите на брайлевском приборе примеры:
                    <br>
                    ОДИН ПЛЮС ОДИН РАВНО ДВА
                    <br>
                    ТРИ МИНУС ОДИН РАВНО ДВА
                    <br>
                    после чего проверьте себя по третьей снизу строке на странице 65 в пособии.
                    Обратите внимание: перед знаками арифметических действий надо ставить пробел,
                    но после них пробел не делается.
                    """
        ).annotate(StepAnnotation.golubinaBookRequired, StepAnnotation.slateStylusRequired)

        +Info(InfoInterpolation.run {
            """
                Урок $iLesson - математические символы - окончен.
                <br>
                В следующих двух уроках мы бегло ознакомимся с обозначениями латинских и греческих
                букв.
                """
        })
    }
    lesson("Латинский алфавит") {
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: латинский алфавит.</b>
                <br><br>
                В этом уроке собраны все буквы латинского алфавита. Каждую из них нужно сперва
                прочесть, а затем ввести в шеститочии на экране.
                <br>
                Слова на латинице внутри русского текста выделяются специальным символом 
                <b>"Признак большой буквы латинского алфавита"</b> (точки 4 и 6) или 
                <b>"Признак малой буквы латинского алфавита"</b> (точка 6).
                """
        })
        +Info(
            """
                    Латинский алфавит в книге под редакцией В. В. Голубиной изучается на страницах 
                    85-91. Для каждой буквы в пособии приведена русская транскрипция, английское
                    написание шрифтом Брайля (вместе с признаком заглавной латинской буквы)
                    и рельефно-графическое изображение.
                    """
        ).annotate(StepAnnotation.golubinaBookRequired)
        +Show(content.markers.getValue(MarkerType.LatinCapital))
        +Input(content.markers.getValue(MarkerType.LatinCapital))
        +Show(content.markers.getValue(MarkerType.LatinSmall))
        +Input(content.markers.getValue(MarkerType.LatinSmall))
        showAndInputChars("ABCDEFGHIJKLMNOPQRSTUVWXYZ")
        +Info(
            """
                    В следующих шагах введите по буквам фамилию Луи Брайля, как она пишется во 
                    французском и английском языках: BRAILLE, поставив перед этим признак большой
                    латинской буквы.
                    """
        )
        +Input(content.markers.getValue(MarkerType.LatinCapital))
        inputPhraseByLetters("BRAILLE")
        +Info(InfoInterpolation.run {
            """
               На этом урок $iLesson завершается. В следующем занятии аналогичным образом 
               мы кратко ознакомимся с греческим алфавитом.
            """
        })
    }
    lesson("Ноты") {
        +Info(InfoInterpolation.run {
            """
               <b>Урок $iLesson: Основы нотной грамоты.</b>
                <br><br>
                В этом кратком уроке мы узнаем, как в брайлевской нотации записываются семь нот,
                начиная с ДО и заканчивая СИ.
                <br>
                В зависимости от длительности ноты обозначаются разными шеститочечными символами.
                Здесь приведены те, что соответствуют продолжительности <b>одна восьмая</b>.
            """
        })
        showAndInputMarkers(musicalNotesTypes)
        +Info(
            """
               Ноты длительности <b>четвертная</b> образуются путём добавления точки 6.
               <br>
               Длительности <b>половинная</b> -- путём добавления точки 3.
               <br>
               <b>Целая нота</b> -- путём добавления точек 3 и 6 вместе.
            """
        )
        +Input(additionalContent.markers.getValue(MarkerType.NoteCQuarter))
        +Input(additionalContent.markers.getValue(MarkerType.NoteDHalf))
        +Input(additionalContent.markers.getValue(MarkerType.NoteEFull))
        +Info(
            """
               Есть обозначения для пауз разной длительности (восьмая, четвертная, половинная 
               и целая), но они образованы не путём изменений в точках 5 и 6, а немного иначе.
               В следующих  шагах ознакомимся с этими символами.
            """
        )
        showAndInputMarkers(
            listOf(
                MarkerType.MusicRest8th,
                MarkerType.MusicRest4th,
                MarkerType.MusicRestHalf,
                MarkerType.MusicRestFull
            )
        )
        +Info("""
            Ещё один набор символов, с которыми мы сегодня ознакомимся:
            <br>
            Знаки альтерации - диез, бемоль и бекар;
            <b>Музыкальный перенос</b> - аналог обычного текстового переноса в нотах.
            Он обозначается точкой 4, как и обозначение шестой октавы, но, поскольку ставится всегда
            в конце строки, а не в начале, то неоднозначности не возникает.
        """)
        +Show(content.markers.getValue(MarkerType.MusicSharp))
        +Show(content.markers.getValue(MarkerType.MusicFlat))
        +Show(content.markers.getValue(MarkerType.MusicNatural))
        +Show(content.markers.getValue(MarkerType.MusicHyphen))
        +Info("""
            Каждая строка в нотах должна начинаться с обозначения октавы. В следующих шагах
            посмотрим на эти символы.
        """)
        +Show(content.markers.getValue(MarkerType.OctaveMarkBig))
        +Show(content.markers.getValue(MarkerType.OctaveMarkSmall))
        +Show(content.markers.getValue(MarkerType.OctaveMark1))
        +Show(content.markers.getValue(MarkerType.OctaveMark2))
        +Show(content.markers.getValue(MarkerType.OctaveMark3))
        +Show(content.markers.getValue(MarkerType.OctaveMark4))
        +Show(content.markers.getValue(MarkerType.CounterOctaveMark))
        +Info(InfoInterpolation.run {
            """
                Урок $iLesson на этом завершается.
                <br>
                В заключение стоит отметить:
                Луи Брайль был музыкантом и изначально позаботился о том, чтобы его система могла
                представить ноты любой сложности. В рельефно-точечной нотной грамоте более 60
                различных символов; некоторые из них обозначаются несколькими шеститочиями.
                Конечно же, мы не имеем возможности изучить их все.
            """
        })
    }
    lesson("Греческий алфавит") {
        +Info(InfoInterpolation.run {
            """
                <b>Урок $iLesson: греческий алфавит.</b>
                <br><br>
                Последний урок в нашем курсе посвящён греческому алфавиту. При вставке заглавных
                греческих букв в русском тексте ставится специальный символ <b>"Признак большой
                буквы греческого алфавита"</b>.
                """
        })
        +Show(content.markers.getValue(MarkerType.GreekCapital))
        +Input(content.markers.getValue(MarkerType.GreekCapital))
        +Info(
            """
                    Пособие под редакцией В. Голубиной включает и греческий алфавит. Его можно найти
                    на страницах 93-99. Для каждой буквы приведено её название (на русском языке),
                    обозначение в системе Брайля (вместе с признаком заглавной буквы), а также
                    рельефно-графическое изображение.
                    """
        ).annotate(StepAnnotation.golubinaBookRequired)
        showAndInputChars("ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΤΥΦΧΨΩ")
        +Info("""
            Мы изучили греческие символы так, как они пишутся в советских и российских математических учебниках.
            Есть и другие варианты записи греческих брайлевских букв, но в нашем кратком курсе они не рассматриваются.
        """)
        +LastInfo(InfoInterpolation.run {
            """
                    Урок $iLesson закончен.
                    <br>
                    Вы дошли до конца курса. Спасибо, что воспользовались нашим обучающим
                    приложением! При желании можно вернутся к ранее пройденному материалу 
                    и повторить его.
                    <br><br>
                    Помните, что для успешного закрепления навыков чтения по Брайлю нужна практика.
                    Мы советуем Вам читать различные книги рельефно-точечным шрифтом. Желаем вам
                    приятного опыта использования алфавита Луи Брайля!
                    """
        })
    }
}
